import greenfoot.*;

//This is the import to get access to the camera object
import packages.ui.Camera;

//This is used to display some text. Not nessecary for the actual splitscreen
import packages.ui.Text;

//This is used to use relative positions. Not nessecary for the actual splitscreen
import packages.ui.UIWorld;




/**
 * This has the code that adds the cameras.
 * 
 * <p>The split screen function is actually achieved by simply playing two cameras in the same world.
 * 
 * <p>It uses 'UIWorld' to get easy access to the fps counter and can use relative positions
 * (All my implementations, all included).
 */
public class MyWorld extends UIWorld {

    //Everything neccesary is being done in the constructor of the world
    public MyWorld() {

        //Create a world with 600x400 pixels. This is the world that will actually be shown.
        super(600, 400, 1);


        //This is where the cameras are created.
        allTheCameraStuff();


        //Creates a background image (behind the cameras).
        GreenfootImage image = new GreenfootImage(600, 400);
        image.setColor(Color.DARK_GRAY);
        image.fill();
        image.setColor(Color.DARK_GRAY.brighter());
        image.fillRect(5, 5, 590, 390);
        image.setColor(Color.DARK_GRAY);
        image.fillRect(295, 5, 10, 390);
        setBackground(image);


        //Adds some visuals (the players signs and the fps counter)
        addFps();
        Color textBg = new Color(0, 0, 0, 100);
        add(new Text("Player 1", 25, Player.colors[0], textBg), 0.25, 0.1);
        add(new Text("Controls: w-a-s-d + shift", 20, Color.BLACK, textBg), 0.25, 0.9);
        add(new Text("Player 2", 25, Player.colors[1], textBg), 0.75, 0.1);
        add(new Text("Controls: arrow keys + space", 20, Color.BLACK, textBg), 0.75, 0.9);

        //Start the scenario (like pressing 'run' on the greenfoot ui).
        Greenfoot.start();
    }





    /**
     * This contains all the stuff that is neccesary for the cameras to work.
     * Everything else is just visual (except the super constructor, obviously).
     */
    private void allTheCameraStuff() {

        //Create a new game. This simply creates a new instance of it. It DOES NOT show the game world.
        Game game = new Game();

        //Create two cameras for the two screens.
        //Each camera takes a width, a height and an actor as input. It will automatically follow that player around.
        //In this case, both screens have s size of 280x380 pixels. They take the two players from the game as input.
        //Each camera will display the given actor. As these are in the same world (->game), the cameras will display
        //the same world. Viola: splitscreen!
        Camera cam1 = new Camera(280, 380, game.p1);
        Camera cam2 = new Camera(280, 380, game.p2);

        //Zoom in on the player 1 camera. Warning: changing zoom decreases performance, and zooming to far in decreases
        //it exponentially as the images to generate become bigger.
        cam1.setZoom(2);

        //Activates performance mode on both cameras. This means that they will only render once per frame no matter
        //what happens. This is fine for this programm, as the time between frames is short and you don't need to see
        //one object moving after another. However for script-like programms that don't use the 'run'-functionallity,
        //this will not work (well).
        cam1.usePerformanceMode = true;
        cam2.usePerformanceMode = true;

        //Add the cameras into the world at the desired locaiton. You can move them later as well.
        addObject(cam1, 150, 200);
        addObject(cam2, 450, 200);

        //That's it for the cameras!
    }
}